// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: attr_value.proto
// Protobuf C++ Version: 6.32.1

#include "attr_value.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
namespace opencv_tensorflow {

inline constexpr AttrValue_ListValue::Impl_::Impl_(
    ::_pbi::ConstantInitialized) noexcept
      : s_{},
        i_{},
        _i_cached_byte_size_{0},
        f_{},
        b_{},
        type_{},
        _type_cached_byte_size_{0},
        shape_{},
        tensor_{},
        _cached_size_{0} {}

template <typename>
PROTOBUF_CONSTEXPR AttrValue_ListValue::AttrValue_ListValue(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(AttrValue_ListValue_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(::_pbi::ConstantInitialized()) {
}
struct AttrValue_ListValueDefaultTypeInternal {
  PROTOBUF_CONSTEXPR AttrValue_ListValueDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~AttrValue_ListValueDefaultTypeInternal() {}
  union {
    AttrValue_ListValue _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 AttrValue_ListValueDefaultTypeInternal _AttrValue_ListValue_default_instance_;

inline constexpr AttrValue::Impl_::Impl_(
    ::_pbi::ConstantInitialized) noexcept
      : value_{},
        _cached_size_{0},
        _oneof_case_{} {}

template <typename>
PROTOBUF_CONSTEXPR AttrValue::AttrValue(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(AttrValue_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(::_pbi::ConstantInitialized()) {
}
struct AttrValueDefaultTypeInternal {
  PROTOBUF_CONSTEXPR AttrValueDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~AttrValueDefaultTypeInternal() {}
  union {
    AttrValue _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 AttrValueDefaultTypeInternal _AttrValue_default_instance_;

inline constexpr NameAttrList::Impl_::Impl_(
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        attr_{},
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()) {}

template <typename>
PROTOBUF_CONSTEXPR NameAttrList::NameAttrList(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(NameAttrList_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(::_pbi::ConstantInitialized()) {
}
struct NameAttrListDefaultTypeInternal {
  PROTOBUF_CONSTEXPR NameAttrListDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~NameAttrListDefaultTypeInternal() {}
  union {
    NameAttrList _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 NameAttrListDefaultTypeInternal _NameAttrList_default_instance_;
template <typename>
PROTOBUF_CONSTEXPR NameAttrList_AttrEntry_DoNotUse::NameAttrList_AttrEntry_DoNotUse(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : NameAttrList_AttrEntry_DoNotUse::MapEntry(NameAttrList_AttrEntry_DoNotUse_class_data_.base()){}
#else   // PROTOBUF_CUSTOM_VTABLE
    : NameAttrList_AttrEntry_DoNotUse::MapEntry() {
}
#endif  // PROTOBUF_CUSTOM_VTABLE
struct NameAttrList_AttrEntry_DoNotUseDefaultTypeInternal {
  PROTOBUF_CONSTEXPR NameAttrList_AttrEntry_DoNotUseDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~NameAttrList_AttrEntry_DoNotUseDefaultTypeInternal() {}
  union {
    NameAttrList_AttrEntry_DoNotUse _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 NameAttrList_AttrEntry_DoNotUseDefaultTypeInternal _NameAttrList_AttrEntry_DoNotUse_default_instance_;
}  // namespace opencv_tensorflow
static constexpr const ::_pb::EnumDescriptor *PROTOBUF_NONNULL *PROTOBUF_NULLABLE
    file_level_enum_descriptors_attr_5fvalue_2eproto = nullptr;
static constexpr const ::_pb::ServiceDescriptor *PROTOBUF_NONNULL *PROTOBUF_NULLABLE
    file_level_service_descriptors_attr_5fvalue_2eproto = nullptr;
const ::uint32_t
    TableStruct_attr_5fvalue_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x000, // bitmap
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue_ListValue, _impl_.s_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue_ListValue, _impl_.i_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue_ListValue, _impl_.f_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue_ListValue, _impl_.b_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue_ListValue, _impl_.type_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue_ListValue, _impl_.shape_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue_ListValue, _impl_.tensor_),
        0x004, // bitmap
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_._oneof_case_[0]),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_.value_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_.value_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_.value_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_.value_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_.value_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_.value_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_.value_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_.value_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_.value_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_.value_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_.value_),
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::NameAttrList_AttrEntry_DoNotUse, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::NameAttrList_AttrEntry_DoNotUse, _impl_.key_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::NameAttrList_AttrEntry_DoNotUse, _impl_.value_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::NameAttrList, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::NameAttrList, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::NameAttrList, _impl_.attr_),
        0,
        ~0u,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::opencv_tensorflow::AttrValue_ListValue)},
        {8, sizeof(::opencv_tensorflow::AttrValue)},
        {21, sizeof(::opencv_tensorflow::NameAttrList_AttrEntry_DoNotUse)},
        {28, sizeof(::opencv_tensorflow::NameAttrList)},
};
static const ::_pb::Message* PROTOBUF_NONNULL const file_default_instances[] = {
    &::opencv_tensorflow::_AttrValue_ListValue_default_instance_._instance,
    &::opencv_tensorflow::_AttrValue_default_instance_._instance,
    &::opencv_tensorflow::_NameAttrList_AttrEntry_DoNotUse_default_instance_._instance,
    &::opencv_tensorflow::_NameAttrList_default_instance_._instance,
};
const char descriptor_table_protodef_attr_5fvalue_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n\020attr_value.proto\022\021opencv_tensorflow\032\014t"
    "ensor.proto\032\022tensor_shape.proto\032\013types.p"
    "roto\"\266\004\n\tAttrValue\022\013\n\001s\030\002 \001(\014H\000\022\013\n\001i\030\003 \001"
    "(\003H\000\022\013\n\001f\030\004 \001(\002H\000\022\013\n\001b\030\005 \001(\010H\000\022+\n\004type\030\006"
    " \001(\0162\033.opencv_tensorflow.DataTypeH\000\0224\n\005s"
    "hape\030\007 \001(\0132#.opencv_tensorflow.TensorSha"
    "peProtoH\000\0220\n\006tensor\030\010 \001(\0132\036.opencv_tenso"
    "rflow.TensorProtoH\000\0226\n\004list\030\001 \001(\0132&.open"
    "cv_tensorflow.AttrValue.ListValueH\000\022/\n\004f"
    "unc\030\n \001(\0132\037.opencv_tensorflow.NameAttrLi"
    "stH\000\022\025\n\013placeholder\030\t \001(\tH\000\032\326\001\n\tListValu"
    "e\022\t\n\001s\030\002 \003(\014\022\r\n\001i\030\003 \003(\003B\002\020\001\022\r\n\001f\030\004 \003(\002B\002"
    "\020\001\022\r\n\001b\030\005 \003(\010B\002\020\001\022-\n\004type\030\006 \003(\0162\033.opencv"
    "_tensorflow.DataTypeB\002\020\001\0222\n\005shape\030\007 \003(\0132"
    "#.opencv_tensorflow.TensorShapeProto\022.\n\006"
    "tensor\030\010 \003(\0132\036.opencv_tensorflow.TensorP"
    "rotoB\007\n\005value\"\240\001\n\014NameAttrList\022\014\n\004name\030\001"
    " \001(\t\0227\n\004attr\030\002 \003(\0132).opencv_tensorflow.N"
    "ameAttrList.AttrEntry\032I\n\tAttrEntry\022\013\n\003ke"
    "y\030\001 \001(\t\022+\n\005value\030\002 \001(\0132\034.opencv_tensorfl"
    "ow.AttrValue:\0028\001B0\n\030org.tensorflow.frame"
    "workB\017AttrValueProtosP\001\370\001\001b\006proto3"
};
static const ::_pbi::DescriptorTable* PROTOBUF_NONNULL const
    descriptor_table_attr_5fvalue_2eproto_deps[3] = {
        &::descriptor_table_tensor_2eproto,
        &::descriptor_table_tensor_5fshape_2eproto,
        &::descriptor_table_types_2eproto,
};
static ::absl::once_flag descriptor_table_attr_5fvalue_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_attr_5fvalue_2eproto = {
    false,
    false,
    874,
    descriptor_table_protodef_attr_5fvalue_2eproto,
    "attr_value.proto",
    &descriptor_table_attr_5fvalue_2eproto_once,
    descriptor_table_attr_5fvalue_2eproto_deps,
    3,
    4,
    schemas,
    file_default_instances,
    TableStruct_attr_5fvalue_2eproto::offsets,
    file_level_enum_descriptors_attr_5fvalue_2eproto,
    file_level_service_descriptors_attr_5fvalue_2eproto,
};
namespace opencv_tensorflow {
// ===================================================================

class AttrValue_ListValue::_Internal {
 public:
};

void AttrValue_ListValue::clear_shape() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.shape_.Clear();
}
void AttrValue_ListValue::clear_tensor() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.tensor_.Clear();
}
AttrValue_ListValue::AttrValue_ListValue(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AttrValue_ListValue_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opencv_tensorflow.AttrValue.ListValue)
}
PROTOBUF_NDEBUG_INLINE AttrValue_ListValue::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opencv_tensorflow::AttrValue_ListValue& from_msg)
      : s_{visibility, arena, from.s_},
        i_{visibility, arena, from.i_},
        _i_cached_byte_size_{0},
        f_{visibility, arena, from.f_},
        b_{visibility, arena, from.b_},
        type_{visibility, arena, from.type_},
        _type_cached_byte_size_{0},
        shape_{visibility, arena, from.shape_},
        tensor_{visibility, arena, from.tensor_},
        _cached_size_{0} {}

AttrValue_ListValue::AttrValue_ListValue(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const AttrValue_ListValue& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AttrValue_ListValue_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  AttrValue_ListValue* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:opencv_tensorflow.AttrValue.ListValue)
}
PROTOBUF_NDEBUG_INLINE AttrValue_ListValue::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : s_{visibility, arena},
        i_{visibility, arena},
        _i_cached_byte_size_{0},
        f_{visibility, arena},
        b_{visibility, arena},
        type_{visibility, arena},
        _type_cached_byte_size_{0},
        shape_{visibility, arena},
        tensor_{visibility, arena},
        _cached_size_{0} {}

inline void AttrValue_ListValue::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
AttrValue_ListValue::~AttrValue_ListValue() {
  // @@protoc_insertion_point(destructor:opencv_tensorflow.AttrValue.ListValue)
  SharedDtor(*this);
}
inline void AttrValue_ListValue::SharedDtor(MessageLite& self) {
  AttrValue_ListValue& this_ = static_cast<AttrValue_ListValue&>(self);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL AttrValue_ListValue::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) AttrValue_ListValue(arena);
}
constexpr auto AttrValue_ListValue::InternalNewImpl_() {
  constexpr auto arena_bits = ::google::protobuf::internal::EncodePlacementArenaOffsets({
      PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.s_) +
          decltype(AttrValue_ListValue::_impl_.s_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
      PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.i_) +
          decltype(AttrValue_ListValue::_impl_.i_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
      PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.f_) +
          decltype(AttrValue_ListValue::_impl_.f_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
      PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.b_) +
          decltype(AttrValue_ListValue::_impl_.b_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
      PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.type_) +
          decltype(AttrValue_ListValue::_impl_.type_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
      PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.shape_) +
          decltype(AttrValue_ListValue::_impl_.shape_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
      PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.tensor_) +
          decltype(AttrValue_ListValue::_impl_.tensor_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
  });
  if (arena_bits.has_value()) {
    return ::google::protobuf::internal::MessageCreator::ZeroInit(
        sizeof(AttrValue_ListValue), alignof(AttrValue_ListValue), *arena_bits);
  } else {
    return ::google::protobuf::internal::MessageCreator(&AttrValue_ListValue::PlacementNew_,
                                 sizeof(AttrValue_ListValue),
                                 alignof(AttrValue_ListValue));
  }
}
constexpr auto AttrValue_ListValue::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_AttrValue_ListValue_default_instance_._instance,
          &_table_.header,
          nullptr,  // OnDemandRegisterArenaDtor
          nullptr,  // IsInitialized
          &AttrValue_ListValue::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<AttrValue_ListValue>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &AttrValue_ListValue::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<AttrValue_ListValue>(), &AttrValue_ListValue::ByteSizeLong,
              &AttrValue_ListValue::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_._cached_size_),
          false,
      },
      &AttrValue_ListValue::kDescriptorMethods,
      &descriptor_table_attr_5fvalue_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull AttrValue_ListValue_class_data_ =
        AttrValue_ListValue::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AttrValue_ListValue::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AttrValue_ListValue_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(AttrValue_ListValue_class_data_.tc_table);
  return AttrValue_ListValue_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 7, 2, 0, 2>
AttrValue_ListValue::_table_ = {
  {
    0,  // no _has_bits_
    0, // no _extensions_
    8, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967041,  // skipmap
    offsetof(decltype(_table_), field_entries),
    7,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    AttrValue_ListValue_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::opencv_tensorflow::AttrValue_ListValue>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // repeated .opencv_tensorflow.TensorProto tensor = 8;
    {::_pbi::TcParser::FastMtR1,
     {66, 63, 1, PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.tensor_)}},
    {::_pbi::TcParser::MiniParse, {}},
    // repeated bytes s = 2;
    {::_pbi::TcParser::FastBR1,
     {18, 63, 0, PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.s_)}},
    // repeated int64 i = 3 [packed = true];
    {::_pbi::TcParser::FastV64P1,
     {26, 63, 0, PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.i_)}},
    // repeated float f = 4 [packed = true];
    {::_pbi::TcParser::FastF32P1,
     {34, 63, 0, PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.f_)}},
    // repeated bool b = 5 [packed = true];
    {::_pbi::TcParser::FastV8P1,
     {42, 63, 0, PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.b_)}},
    // repeated .opencv_tensorflow.DataType type = 6 [packed = true];
    {::_pbi::TcParser::FastV32P1,
     {50, 63, 0, PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.type_)}},
    // repeated .opencv_tensorflow.TensorShapeProto shape = 7;
    {::_pbi::TcParser::FastMtR1,
     {58, 63, 0, PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.shape_)}},
  }}, {{
    65535, 65535
  }}, {{
    // repeated bytes s = 2;
    {PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.s_), 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kBytes | ::_fl::kRepSString)},
    // repeated int64 i = 3 [packed = true];
    {PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.i_), 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedInt64)},
    // repeated float f = 4 [packed = true];
    {PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.f_), 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedFloat)},
    // repeated bool b = 5 [packed = true];
    {PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.b_), 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedBool)},
    // repeated .opencv_tensorflow.DataType type = 6 [packed = true];
    {PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.type_), 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedOpenEnum)},
    // repeated .opencv_tensorflow.TensorShapeProto shape = 7;
    {PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.shape_), 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    // repeated .opencv_tensorflow.TensorProto tensor = 8;
    {PROTOBUF_FIELD_OFFSET(AttrValue_ListValue, _impl_.tensor_), 0, 1, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::TensorShapeProto>()},
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::TensorProto>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void AttrValue_ListValue::Clear() {
// @@protoc_insertion_point(message_clear_start:opencv_tensorflow.AttrValue.ListValue)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  _impl_.s_.Clear();
  _impl_.i_.Clear();
  _impl_.f_.Clear();
  _impl_.b_.Clear();
  _impl_.type_.Clear();
  _impl_.shape_.Clear();
  _impl_.tensor_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL AttrValue_ListValue::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const AttrValue_ListValue& this_ = static_cast<const AttrValue_ListValue&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL AttrValue_ListValue::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const AttrValue_ListValue& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opencv_tensorflow.AttrValue.ListValue)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  // repeated bytes s = 2;
  for (int i = 0, n = this_._internal_s_size(); i < n; ++i) {
    const auto& s = this_._internal_s().Get(i);
    target = stream->WriteBytes(2, s, target);
  }

  // repeated int64 i = 3 [packed = true];
  {
    int byte_size = this_._impl_._i_cached_byte_size_.Get();
    if (byte_size > 0) {
      target = stream->WriteInt64Packed(
          3, this_._internal_i(), byte_size, target);
    }
  }

  // repeated float f = 4 [packed = true];
  if (this_._internal_f_size() > 0) {
    target = stream->WriteFixedPacked(4, this_._internal_f(), target);
  }

  // repeated bool b = 5 [packed = true];
  if (this_._internal_b_size() > 0) {
    target = stream->WriteFixedPacked(5, this_._internal_b(), target);
  }

  // repeated .opencv_tensorflow.DataType type = 6 [packed = true];
  {
    ::size_t byte_size = this_._impl_._type_cached_byte_size_.Get();
    if (byte_size > 0) {
      target = stream->WriteEnumPacked(
          6, this_._internal_type(), byte_size, target);
    }
  }

  // repeated .opencv_tensorflow.TensorShapeProto shape = 7;
  for (unsigned i = 0, n = static_cast<unsigned>(
                           this_._internal_shape_size());
       i < n; i++) {
    const auto& repfield = this_._internal_shape().Get(i);
    target =
        ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
            7, repfield, repfield.GetCachedSize(),
            target, stream);
  }

  // repeated .opencv_tensorflow.TensorProto tensor = 8;
  for (unsigned i = 0, n = static_cast<unsigned>(
                           this_._internal_tensor_size());
       i < n; i++) {
    const auto& repfield = this_._internal_tensor().Get(i);
    target =
        ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
            8, repfield, repfield.GetCachedSize(),
            target, stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opencv_tensorflow.AttrValue.ListValue)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t AttrValue_ListValue::ByteSizeLong(const MessageLite& base) {
  const AttrValue_ListValue& this_ = static_cast<const AttrValue_ListValue&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t AttrValue_ListValue::ByteSizeLong() const {
  const AttrValue_ListValue& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opencv_tensorflow.AttrValue.ListValue)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated bytes s = 2;
    {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_s().size());
      for (int i = 0, n = this_._internal_s().size(); i < n; ++i) {
        total_size += ::google::protobuf::internal::WireFormatLite::BytesSize(
            this_._internal_s().Get(i));
      }
    }
    // repeated int64 i = 3 [packed = true];
    {
      total_size +=
          ::_pbi::WireFormatLite::Int64SizeWithPackedTagSize(
              this_._internal_i(), 1,
              this_._impl_._i_cached_byte_size_);
    }
    // repeated float f = 4 [packed = true];
    {
      ::size_t data_size = ::size_t{4} *
          ::_pbi::FromIntSize(this_._internal_f_size());
      ::size_t tag_size = data_size == 0
          ? 0
          : 1 + ::_pbi::WireFormatLite::Int32Size(
                              static_cast<::int32_t>(data_size));
      total_size += tag_size + data_size;
    }
    // repeated bool b = 5 [packed = true];
    {
      ::size_t data_size = ::size_t{1} *
          ::_pbi::FromIntSize(this_._internal_b_size());
      ::size_t tag_size = data_size == 0
          ? 0
          : 1 + ::_pbi::WireFormatLite::Int32Size(
                              static_cast<::int32_t>(data_size));
      total_size += tag_size + data_size;
    }
    // repeated .opencv_tensorflow.DataType type = 6 [packed = true];
    {
      total_size += ::_pbi::WireFormatLite::EnumSizeWithPackedTagSize(
          this_._internal_type(), 1, this_._impl_._type_cached_byte_size_);
    }
    // repeated .opencv_tensorflow.TensorShapeProto shape = 7;
    {
      total_size += 1UL * this_._internal_shape_size();
      for (const auto& msg : this_._internal_shape()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // repeated .opencv_tensorflow.TensorProto tensor = 8;
    {
      total_size += 1UL * this_._internal_tensor_size();
      for (const auto& msg : this_._internal_tensor()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void AttrValue_ListValue::MergeImpl(::google::protobuf::MessageLite& to_msg, const ::google::protobuf::MessageLite& from_msg) {
  auto* const _this = static_cast<AttrValue_ListValue*>(&to_msg);
  auto& from = static_cast<const AttrValue_ListValue&>(from_msg);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    from.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:opencv_tensorflow.AttrValue.ListValue)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  _this->_internal_mutable_s()->MergeFrom(from._internal_s());
  _this->_internal_mutable_i()->MergeFrom(from._internal_i());
  _this->_internal_mutable_f()->MergeFrom(from._internal_f());
  _this->_internal_mutable_b()->MergeFrom(from._internal_b());
  _this->_internal_mutable_type()->MergeFrom(from._internal_type());
  _this->_internal_mutable_shape()->MergeFrom(
      from._internal_shape());
  _this->_internal_mutable_tensor()->MergeFrom(
      from._internal_tensor());
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(from._internal_metadata_);
}

void AttrValue_ListValue::CopyFrom(const AttrValue_ListValue& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:opencv_tensorflow.AttrValue.ListValue)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void AttrValue_ListValue::InternalSwap(AttrValue_ListValue* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  _impl_.s_.InternalSwap(&other->_impl_.s_);
  _impl_.i_.InternalSwap(&other->_impl_.i_);
  _impl_.f_.InternalSwap(&other->_impl_.f_);
  _impl_.b_.InternalSwap(&other->_impl_.b_);
  _impl_.type_.InternalSwap(&other->_impl_.type_);
  _impl_.shape_.InternalSwap(&other->_impl_.shape_);
  _impl_.tensor_.InternalSwap(&other->_impl_.tensor_);
}

::google::protobuf::Metadata AttrValue_ListValue::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class AttrValue::_Internal {
 public:
  static constexpr ::int32_t kOneofCaseOffset =
      PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::AttrValue, _impl_._oneof_case_);
};

void AttrValue::set_allocated_shape(::opencv_tensorflow::TensorShapeProto* PROTOBUF_NULLABLE shape) {
  ::google::protobuf::Arena* message_arena = GetArena();
  clear_value();
  if (shape) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(shape)->GetArena();
    if (message_arena != submessage_arena) {
      shape = ::google::protobuf::internal::GetOwnedMessage(message_arena, shape, submessage_arena);
    }
    set_has_shape();
    _impl_.value_.shape_ = shape;
  }
  // @@protoc_insertion_point(field_set_allocated:opencv_tensorflow.AttrValue.shape)
}
void AttrValue::clear_shape() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() == kShape) {
    if (GetArena() == nullptr) {
      delete _impl_.value_.shape_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.value_.shape_);
    }
    clear_has_value();
  }
}
void AttrValue::set_allocated_tensor(::opencv_tensorflow::TensorProto* PROTOBUF_NULLABLE tensor) {
  ::google::protobuf::Arena* message_arena = GetArena();
  clear_value();
  if (tensor) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(tensor)->GetArena();
    if (message_arena != submessage_arena) {
      tensor = ::google::protobuf::internal::GetOwnedMessage(message_arena, tensor, submessage_arena);
    }
    set_has_tensor();
    _impl_.value_.tensor_ = tensor;
  }
  // @@protoc_insertion_point(field_set_allocated:opencv_tensorflow.AttrValue.tensor)
}
void AttrValue::clear_tensor() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value_case() == kTensor) {
    if (GetArena() == nullptr) {
      delete _impl_.value_.tensor_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.value_.tensor_);
    }
    clear_has_value();
  }
}
void AttrValue::set_allocated_list(::opencv_tensorflow::AttrValue_ListValue* PROTOBUF_NULLABLE list) {
  ::google::protobuf::Arena* message_arena = GetArena();
  clear_value();
  if (list) {
    ::google::protobuf::Arena* submessage_arena = list->GetArena();
    if (message_arena != submessage_arena) {
      list = ::google::protobuf::internal::GetOwnedMessage(message_arena, list, submessage_arena);
    }
    set_has_list();
    _impl_.value_.list_ = list;
  }
  // @@protoc_insertion_point(field_set_allocated:opencv_tensorflow.AttrValue.list)
}
void AttrValue::set_allocated_func(::opencv_tensorflow::NameAttrList* PROTOBUF_NULLABLE func) {
  ::google::protobuf::Arena* message_arena = GetArena();
  clear_value();
  if (func) {
    ::google::protobuf::Arena* submessage_arena = func->GetArena();
    if (message_arena != submessage_arena) {
      func = ::google::protobuf::internal::GetOwnedMessage(message_arena, func, submessage_arena);
    }
    set_has_func();
    _impl_.value_.func_ = func;
  }
  // @@protoc_insertion_point(field_set_allocated:opencv_tensorflow.AttrValue.func)
}
AttrValue::AttrValue(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AttrValue_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opencv_tensorflow.AttrValue)
}
PROTOBUF_NDEBUG_INLINE AttrValue::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opencv_tensorflow::AttrValue& from_msg)
      : value_{},
        _cached_size_{0},
        _oneof_case_{from._oneof_case_[0]} {}

AttrValue::AttrValue(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const AttrValue& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AttrValue_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  AttrValue* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  switch (value_case()) {
    case VALUE_NOT_SET:
      break;
      case kS:
        new (&_impl_.value_.s_) decltype(_impl_.value_.s_){arena, from._impl_.value_.s_};
        break;
      case kI:
        _impl_.value_.i_ = from._impl_.value_.i_;
        break;
      case kF:
        _impl_.value_.f_ = from._impl_.value_.f_;
        break;
      case kB:
        _impl_.value_.b_ = from._impl_.value_.b_;
        break;
      case kType:
        _impl_.value_.type_ = from._impl_.value_.type_;
        break;
      case kShape:
        _impl_.value_.shape_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.value_.shape_);
        break;
      case kTensor:
        _impl_.value_.tensor_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.value_.tensor_);
        break;
      case kList:
        _impl_.value_.list_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.value_.list_);
        break;
      case kFunc:
        _impl_.value_.func_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.value_.func_);
        break;
      case kPlaceholder:
        new (&_impl_.value_.placeholder_) decltype(_impl_.value_.placeholder_){arena, from._impl_.value_.placeholder_};
        break;
  }

  // @@protoc_insertion_point(copy_constructor:opencv_tensorflow.AttrValue)
}
PROTOBUF_NDEBUG_INLINE AttrValue::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : value_{},
        _cached_size_{0},
        _oneof_case_{} {}

inline void AttrValue::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
AttrValue::~AttrValue() {
  // @@protoc_insertion_point(destructor:opencv_tensorflow.AttrValue)
  SharedDtor(*this);
}
inline void AttrValue::SharedDtor(MessageLite& self) {
  AttrValue& this_ = static_cast<AttrValue&>(self);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  if (this_.has_value()) {
    this_.clear_value();
  }
  this_._impl_.~Impl_();
}

void AttrValue::clear_value() {
// @@protoc_insertion_point(one_of_clear_start:opencv_tensorflow.AttrValue)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  switch (value_case()) {
    case kS: {
      _impl_.value_.s_.Destroy();
      break;
    }
    case kI: {
      // No need to clear
      break;
    }
    case kF: {
      // No need to clear
      break;
    }
    case kB: {
      // No need to clear
      break;
    }
    case kType: {
      // No need to clear
      break;
    }
    case kShape: {
      if (GetArena() == nullptr) {
        delete _impl_.value_.shape_;
      } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
        ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.value_.shape_);
      }
      break;
    }
    case kTensor: {
      if (GetArena() == nullptr) {
        delete _impl_.value_.tensor_;
      } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
        ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.value_.tensor_);
      }
      break;
    }
    case kList: {
      if (GetArena() == nullptr) {
        delete _impl_.value_.list_;
      } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
        ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.value_.list_);
      }
      break;
    }
    case kFunc: {
      if (GetArena() == nullptr) {
        delete _impl_.value_.func_;
      } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
        ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.value_.func_);
      }
      break;
    }
    case kPlaceholder: {
      _impl_.value_.placeholder_.Destroy();
      break;
    }
    case VALUE_NOT_SET: {
      break;
    }
  }
  _impl_._oneof_case_[0] = VALUE_NOT_SET;
}


inline void* PROTOBUF_NONNULL AttrValue::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) AttrValue(arena);
}
constexpr auto AttrValue::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(AttrValue),
                                            alignof(AttrValue));
}
constexpr auto AttrValue::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_AttrValue_default_instance_._instance,
          &_table_.header,
          nullptr,  // OnDemandRegisterArenaDtor
          nullptr,  // IsInitialized
          &AttrValue::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<AttrValue>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &AttrValue::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<AttrValue>(), &AttrValue::ByteSizeLong,
              &AttrValue::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(AttrValue, _impl_._cached_size_),
          false,
      },
      &AttrValue::kDescriptorMethods,
      &descriptor_table_attr_5fvalue_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull AttrValue_class_data_ =
        AttrValue::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AttrValue::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AttrValue_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(AttrValue_class_data_.tc_table);
  return AttrValue_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<0, 10, 4, 55, 2>
AttrValue::_table_ = {
  {
    0,  // no _has_bits_
    0, // no _extensions_
    10, 0,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294966272,  // skipmap
    offsetof(decltype(_table_), field_entries),
    10,  // num_field_entries
    4,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    AttrValue_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::opencv_tensorflow::AttrValue>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .opencv_tensorflow.AttrValue.ListValue list = 1;
    {PROTOBUF_FIELD_OFFSET(AttrValue, _impl_.value_.list_), _Internal::kOneofCaseOffset + 0, 0, (0 | ::_fl::kFcOneof | ::_fl::kMessage | ::_fl::kTvTable)},
    // bytes s = 2;
    {PROTOBUF_FIELD_OFFSET(AttrValue, _impl_.value_.s_), _Internal::kOneofCaseOffset + 0, 0, (0 | ::_fl::kFcOneof | ::_fl::kBytes | ::_fl::kRepAString)},
    // int64 i = 3;
    {PROTOBUF_FIELD_OFFSET(AttrValue, _impl_.value_.i_), _Internal::kOneofCaseOffset + 0, 0, (0 | ::_fl::kFcOneof | ::_fl::kInt64)},
    // float f = 4;
    {PROTOBUF_FIELD_OFFSET(AttrValue, _impl_.value_.f_), _Internal::kOneofCaseOffset + 0, 0, (0 | ::_fl::kFcOneof | ::_fl::kFloat)},
    // bool b = 5;
    {PROTOBUF_FIELD_OFFSET(AttrValue, _impl_.value_.b_), _Internal::kOneofCaseOffset + 0, 0, (0 | ::_fl::kFcOneof | ::_fl::kBool)},
    // .opencv_tensorflow.DataType type = 6;
    {PROTOBUF_FIELD_OFFSET(AttrValue, _impl_.value_.type_), _Internal::kOneofCaseOffset + 0, 0, (0 | ::_fl::kFcOneof | ::_fl::kOpenEnum)},
    // .opencv_tensorflow.TensorShapeProto shape = 7;
    {PROTOBUF_FIELD_OFFSET(AttrValue, _impl_.value_.shape_), _Internal::kOneofCaseOffset + 0, 1, (0 | ::_fl::kFcOneof | ::_fl::kMessage | ::_fl::kTvTable)},
    // .opencv_tensorflow.TensorProto tensor = 8;
    {PROTOBUF_FIELD_OFFSET(AttrValue, _impl_.value_.tensor_), _Internal::kOneofCaseOffset + 0, 2, (0 | ::_fl::kFcOneof | ::_fl::kMessage | ::_fl::kTvTable)},
    // string placeholder = 9;
    {PROTOBUF_FIELD_OFFSET(AttrValue, _impl_.value_.placeholder_), _Internal::kOneofCaseOffset + 0, 0, (0 | ::_fl::kFcOneof | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // .opencv_tensorflow.NameAttrList func = 10;
    {PROTOBUF_FIELD_OFFSET(AttrValue, _impl_.value_.func_), _Internal::kOneofCaseOffset + 0, 3, (0 | ::_fl::kFcOneof | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::AttrValue_ListValue>()},
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::TensorShapeProto>()},
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::TensorProto>()},
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::NameAttrList>()},
  }},
  {{
    "\33\0\0\0\0\0\0\0\0\13\0\0\0\0\0\0"
    "opencv_tensorflow.AttrValue"
    "placeholder"
  }},
};
PROTOBUF_NOINLINE void AttrValue::Clear() {
// @@protoc_insertion_point(message_clear_start:opencv_tensorflow.AttrValue)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  clear_value();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL AttrValue::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const AttrValue& this_ = static_cast<const AttrValue&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL AttrValue::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const AttrValue& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opencv_tensorflow.AttrValue)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  switch (this_.value_case()) {
    case kList: {
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          1, *this_._impl_.value_.list_, this_._impl_.value_.list_->GetCachedSize(), target,
          stream);
      break;
    }
    case kS: {
      const ::std::string& _s = this_._internal_s();
      target = stream->WriteBytesMaybeAliased(2, _s, target);
      break;
    }
    case kI: {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<3>(
              stream, this_._internal_i(), target);
      break;
    }
    case kF: {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteFloatToArray(
          4, this_._internal_f(), target);
      break;
    }
    case kB: {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          5, this_._internal_b(), target);
      break;
    }
    case kType: {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          6, this_._internal_type(), target);
      break;
    }
    case kShape: {
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          7, *this_._impl_.value_.shape_, this_._impl_.value_.shape_->GetCachedSize(), target,
          stream);
      break;
    }
    case kTensor: {
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          8, *this_._impl_.value_.tensor_, this_._impl_.value_.tensor_->GetCachedSize(), target,
          stream);
      break;
    }
    case kPlaceholder: {
      const ::std::string& _s = this_._internal_placeholder();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.AttrValue.placeholder");
      target = stream->WriteStringMaybeAliased(9, _s, target);
      break;
    }
    case kFunc: {
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          10, *this_._impl_.value_.func_, this_._impl_.value_.func_->GetCachedSize(), target,
          stream);
      break;
    }
    default:
      break;
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opencv_tensorflow.AttrValue)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t AttrValue::ByteSizeLong(const MessageLite& base) {
  const AttrValue& this_ = static_cast<const AttrValue&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t AttrValue::ByteSizeLong() const {
  const AttrValue& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opencv_tensorflow.AttrValue)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  switch (this_.value_case()) {
    // bytes s = 2;
    case kS: {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::BytesSize(
                                      this_._internal_s());
      break;
    }
    // int64 i = 3;
    case kI: {
      total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
          this_._internal_i());
      break;
    }
    // float f = 4;
    case kF: {
      total_size += 5;
      break;
    }
    // bool b = 5;
    case kB: {
      total_size += 2;
      break;
    }
    // .opencv_tensorflow.DataType type = 6;
    case kType: {
      total_size += 1 +
                    ::_pbi::WireFormatLite::EnumSize(this_._internal_type());
      break;
    }
    // .opencv_tensorflow.TensorShapeProto shape = 7;
    case kShape: {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.value_.shape_);
      break;
    }
    // .opencv_tensorflow.TensorProto tensor = 8;
    case kTensor: {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.value_.tensor_);
      break;
    }
    // .opencv_tensorflow.AttrValue.ListValue list = 1;
    case kList: {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.value_.list_);
      break;
    }
    // .opencv_tensorflow.NameAttrList func = 10;
    case kFunc: {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.value_.func_);
      break;
    }
    // string placeholder = 9;
    case kPlaceholder: {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_placeholder());
      break;
    }
    case VALUE_NOT_SET: {
      break;
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void AttrValue::MergeImpl(::google::protobuf::MessageLite& to_msg, const ::google::protobuf::MessageLite& from_msg) {
  auto* const _this = static_cast<AttrValue*>(&to_msg);
  auto& from = static_cast<const AttrValue&>(from_msg);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    from.VerifyHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:opencv_tensorflow.AttrValue)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  if (const uint32_t oneof_from_case = from._impl_._oneof_case_[0]) {
    const uint32_t oneof_to_case = _this->_impl_._oneof_case_[0];
    const bool oneof_needs_init = oneof_to_case != oneof_from_case;
    if (oneof_needs_init) {
      if (oneof_to_case != 0) {
        _this->clear_value();
      }
      _this->_impl_._oneof_case_[0] = oneof_from_case;
    }

    switch (oneof_from_case) {
      case kS: {
        if (oneof_needs_init) {
          _this->_impl_.value_.s_.InitDefault();
        }
        _this->_impl_.value_.s_.Set(from._internal_s(), arena);
        break;
      }
      case kI: {
        _this->_impl_.value_.i_ = from._impl_.value_.i_;
        break;
      }
      case kF: {
        _this->_impl_.value_.f_ = from._impl_.value_.f_;
        break;
      }
      case kB: {
        _this->_impl_.value_.b_ = from._impl_.value_.b_;
        break;
      }
      case kType: {
        _this->_impl_.value_.type_ = from._impl_.value_.type_;
        break;
      }
      case kShape: {
        if (oneof_needs_init) {
          _this->_impl_.value_.shape_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.value_.shape_);
        } else {
          _this->_impl_.value_.shape_->MergeFrom(*from._impl_.value_.shape_);
        }
        break;
      }
      case kTensor: {
        if (oneof_needs_init) {
          _this->_impl_.value_.tensor_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.value_.tensor_);
        } else {
          _this->_impl_.value_.tensor_->MergeFrom(*from._impl_.value_.tensor_);
        }
        break;
      }
      case kList: {
        if (oneof_needs_init) {
          _this->_impl_.value_.list_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.value_.list_);
        } else {
          _this->_impl_.value_.list_->MergeFrom(*from._impl_.value_.list_);
        }
        break;
      }
      case kFunc: {
        if (oneof_needs_init) {
          _this->_impl_.value_.func_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.value_.func_);
        } else {
          _this->_impl_.value_.func_->MergeFrom(*from._impl_.value_.func_);
        }
        break;
      }
      case kPlaceholder: {
        if (oneof_needs_init) {
          _this->_impl_.value_.placeholder_.InitDefault();
        }
        _this->_impl_.value_.placeholder_.Set(from._internal_placeholder(), arena);
        break;
      }
      case VALUE_NOT_SET:
        break;
    }
  }
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(from._internal_metadata_);
}

void AttrValue::CopyFrom(const AttrValue& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:opencv_tensorflow.AttrValue)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void AttrValue::InternalSwap(AttrValue* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_.value_, other->_impl_.value_);
  swap(_impl_._oneof_case_[0], other->_impl_._oneof_case_[0]);
}

::google::protobuf::Metadata AttrValue::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

#if defined(PROTOBUF_CUSTOM_VTABLE)
NameAttrList_AttrEntry_DoNotUse::NameAttrList_AttrEntry_DoNotUse()
    : SuperType(NameAttrList_AttrEntry_DoNotUse_class_data_.base()) {}
NameAttrList_AttrEntry_DoNotUse::NameAttrList_AttrEntry_DoNotUse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
    : SuperType(arena, NameAttrList_AttrEntry_DoNotUse_class_data_.base()) {}
#else   // PROTOBUF_CUSTOM_VTABLE
NameAttrList_AttrEntry_DoNotUse::NameAttrList_AttrEntry_DoNotUse() : SuperType() {}
NameAttrList_AttrEntry_DoNotUse::NameAttrList_AttrEntry_DoNotUse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena) : SuperType(arena) {}
#endif  // PROTOBUF_CUSTOM_VTABLE
inline void* PROTOBUF_NONNULL NameAttrList_AttrEntry_DoNotUse::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) NameAttrList_AttrEntry_DoNotUse(arena);
}
constexpr auto NameAttrList_AttrEntry_DoNotUse::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(NameAttrList_AttrEntry_DoNotUse),
                                            alignof(NameAttrList_AttrEntry_DoNotUse));
}
constexpr auto NameAttrList_AttrEntry_DoNotUse::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_NameAttrList_AttrEntry_DoNotUse_default_instance_._instance,
          &_table_.header,
          nullptr,  // OnDemandRegisterArenaDtor
          nullptr,  // IsInitialized
          &NameAttrList_AttrEntry_DoNotUse::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<NameAttrList_AttrEntry_DoNotUse>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &NameAttrList_AttrEntry_DoNotUse::SharedDtor,
          static_cast<void (::google::protobuf::MessageLite::*)()>(&NameAttrList_AttrEntry_DoNotUse::ClearImpl),
              ::google::protobuf::Message::ByteSizeLongImpl, ::google::protobuf::Message::_InternalSerializeImpl
              ,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(NameAttrList_AttrEntry_DoNotUse, _impl_._cached_size_),
          false,
      },
      &NameAttrList_AttrEntry_DoNotUse::kDescriptorMethods,
      &descriptor_table_attr_5fvalue_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull NameAttrList_AttrEntry_DoNotUse_class_data_ =
        NameAttrList_AttrEntry_DoNotUse::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
NameAttrList_AttrEntry_DoNotUse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&NameAttrList_AttrEntry_DoNotUse_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(NameAttrList_AttrEntry_DoNotUse_class_data_.tc_table);
  return NameAttrList_AttrEntry_DoNotUse_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<1, 2, 1, 52, 2>
NameAttrList_AttrEntry_DoNotUse::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(NameAttrList_AttrEntry_DoNotUse, _impl_._has_bits_),
    0, // no _extensions_
    2, 8,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967292,  // skipmap
    offsetof(decltype(_table_), field_entries),
    2,  // num_field_entries
    1,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    NameAttrList_AttrEntry_DoNotUse_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::DiscardEverythingFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::opencv_tensorflow::NameAttrList_AttrEntry_DoNotUse>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // .opencv_tensorflow.AttrValue value = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 0, PROTOBUF_FIELD_OFFSET(NameAttrList_AttrEntry_DoNotUse, _impl_.value_)}},
    // string key = 1;
    {::_pbi::TcParser::FastUS1,
     {10, 0, 0, PROTOBUF_FIELD_OFFSET(NameAttrList_AttrEntry_DoNotUse, _impl_.key_)}},
  }}, {{
    65535, 65535
  }}, {{
    // string key = 1;
    {PROTOBUF_FIELD_OFFSET(NameAttrList_AttrEntry_DoNotUse, _impl_.key_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // .opencv_tensorflow.AttrValue value = 2;
    {PROTOBUF_FIELD_OFFSET(NameAttrList_AttrEntry_DoNotUse, _impl_.value_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::AttrValue>()},
  }},
  {{
    "\50\3\0\0\0\0\0\0"
    "opencv_tensorflow.NameAttrList.AttrEntry"
    "key"
  }},
};
// ===================================================================

class NameAttrList::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<NameAttrList>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(NameAttrList, _impl_._has_bits_);
};

NameAttrList::NameAttrList(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, NameAttrList_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opencv_tensorflow.NameAttrList)
}
PROTOBUF_NDEBUG_INLINE NameAttrList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opencv_tensorflow::NameAttrList& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        attr_{visibility, arena, from.attr_},
        name_(arena, from.name_) {}

NameAttrList::NameAttrList(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const NameAttrList& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, NameAttrList_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  NameAttrList* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:opencv_tensorflow.NameAttrList)
}
PROTOBUF_NDEBUG_INLINE NameAttrList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        attr_{visibility, arena},
        name_(arena) {}

inline void NameAttrList::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
NameAttrList::~NameAttrList() {
  // @@protoc_insertion_point(destructor:opencv_tensorflow.NameAttrList)
  SharedDtor(*this);
}
inline void NameAttrList::SharedDtor(MessageLite& self) {
  NameAttrList& this_ = static_cast<NameAttrList&>(self);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL NameAttrList::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) NameAttrList(arena);
}
constexpr auto NameAttrList::InternalNewImpl_() {
  constexpr auto arena_bits = ::google::protobuf::internal::EncodePlacementArenaOffsets({
      PROTOBUF_FIELD_OFFSET(NameAttrList, _impl_.attr_) +
          decltype(NameAttrList::_impl_.attr_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
      PROTOBUF_FIELD_OFFSET(NameAttrList, _impl_.attr_) +
          decltype(NameAttrList::_impl_.attr_)::
              InternalGetArenaOffsetAlt(
                  ::google::protobuf::Message::internal_visibility()),
  });
  if (arena_bits.has_value()) {
    return ::google::protobuf::internal::MessageCreator::CopyInit(
        sizeof(NameAttrList), alignof(NameAttrList), *arena_bits);
  } else {
    return ::google::protobuf::internal::MessageCreator(&NameAttrList::PlacementNew_,
                                 sizeof(NameAttrList),
                                 alignof(NameAttrList));
  }
}
constexpr auto NameAttrList::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_NameAttrList_default_instance_._instance,
          &_table_.header,
          nullptr,  // OnDemandRegisterArenaDtor
          nullptr,  // IsInitialized
          &NameAttrList::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<NameAttrList>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &NameAttrList::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<NameAttrList>(), &NameAttrList::ByteSizeLong,
              &NameAttrList::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(NameAttrList, _impl_._cached_size_),
          false,
      },
      &NameAttrList::kDescriptorMethods,
      &descriptor_table_attr_5fvalue_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull NameAttrList_class_data_ =
        NameAttrList::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
NameAttrList::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&NameAttrList_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(NameAttrList_class_data_.tc_table);
  return NameAttrList_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<0, 2, 2, 47, 2>
NameAttrList::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(NameAttrList, _impl_._has_bits_),
    0, // no _extensions_
    2, 0,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967292,  // skipmap
    offsetof(decltype(_table_), field_entries),
    2,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    NameAttrList_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::opencv_tensorflow::NameAttrList>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // string name = 1;
    {::_pbi::TcParser::FastUS1,
     {10, 0, 0, PROTOBUF_FIELD_OFFSET(NameAttrList, _impl_.name_)}},
  }}, {{
    65535, 65535
  }}, {{
    // string name = 1;
    {PROTOBUF_FIELD_OFFSET(NameAttrList, _impl_.name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // map<string, .opencv_tensorflow.AttrValue> attr = 2;
    {PROTOBUF_FIELD_OFFSET(NameAttrList, _impl_.attr_), -1, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMap)},
  }},
  {{
      {::_pbi::TcParser::GetMapAuxInfo(1, 0, 0,
                                       9, 11,
                                       0)},
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::AttrValue>()},
  }},
  {{
    "\36\4\4\0\0\0\0\0"
    "opencv_tensorflow.NameAttrList"
    "name"
    "attr"
  }},
};
PROTOBUF_NOINLINE void NameAttrList::Clear() {
// @@protoc_insertion_point(message_clear_start:opencv_tensorflow.NameAttrList)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  _impl_.attr_.Clear();
  cached_has_bits = _impl_._has_bits_[0];
  if ((cached_has_bits & 0x00000001U) != 0) {
    _impl_.name_.ClearNonDefaultToEmpty();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL NameAttrList::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const NameAttrList& this_ = static_cast<const NameAttrList&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL NameAttrList::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const NameAttrList& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opencv_tensorflow.NameAttrList)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  // string name = 1;
  if ((this_._impl_._has_bits_[0] & 0x00000001U) != 0) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.NameAttrList.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // map<string, .opencv_tensorflow.AttrValue> attr = 2;
  if (!this_._internal_attr().empty()) {
    using MapType = ::google::protobuf::Map<::std::string, ::opencv_tensorflow::AttrValue>;
    using WireHelper = _pbi::MapEntryFuncs<::std::string, ::opencv_tensorflow::AttrValue,
                                   _pbi::WireFormatLite::TYPE_STRING,
                                   _pbi::WireFormatLite::TYPE_MESSAGE>;
    const auto& field = this_._internal_attr();

    if (stream->IsSerializationDeterministic() && field.size() > 1) {
      for (const auto& entry : ::google::protobuf::internal::MapSorterPtr<MapType>(field)) {
        target = WireHelper::InternalSerialize(
            2, entry.first, entry.second, target, stream);
        ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            entry.first.data(), static_cast<int>(entry.first.length()),
 ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.NameAttrList.attr");
      }
    } else {
      for (const auto& entry : field) {
        target = WireHelper::InternalSerialize(
            2, entry.first, entry.second, target, stream);
        ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            entry.first.data(), static_cast<int>(entry.first.length()),
 ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.NameAttrList.attr");
      }
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opencv_tensorflow.NameAttrList)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t NameAttrList::ByteSizeLong(const MessageLite& base) {
  const NameAttrList& this_ = static_cast<const NameAttrList&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t NameAttrList::ByteSizeLong() const {
  const NameAttrList& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opencv_tensorflow.NameAttrList)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // map<string, .opencv_tensorflow.AttrValue> attr = 2;
    {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_attr_size());
      for (const auto& entry : this_._internal_attr()) {
        total_size += _pbi::MapEntryFuncs<::std::string, ::opencv_tensorflow::AttrValue,
                                       _pbi::WireFormatLite::TYPE_STRING,
                                       _pbi::WireFormatLite::TYPE_MESSAGE>::ByteSizeLong(entry.first, entry.second);
      }
    }
  }
   {
    // string name = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if ((cached_has_bits & 0x00000001U) != 0) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void NameAttrList::MergeImpl(::google::protobuf::MessageLite& to_msg, const ::google::protobuf::MessageLite& from_msg) {
  auto* const _this = static_cast<NameAttrList*>(&to_msg);
  auto& from = static_cast<const NameAttrList&>(from_msg);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    from.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:opencv_tensorflow.NameAttrList)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  _this->_impl_.attr_.MergeFrom(from._impl_.attr_);
  cached_has_bits = from._impl_._has_bits_[0];
  if ((cached_has_bits & 0x00000001U) != 0) {
    if (!from._internal_name().empty()) {
      _this->_internal_set_name(from._internal_name());
    } else {
      if (_this->_impl_.name_.IsDefault()) {
        _this->_internal_set_name("");
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(from._internal_metadata_);
}

void NameAttrList::CopyFrom(const NameAttrList& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:opencv_tensorflow.NameAttrList)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void NameAttrList::InternalSwap(NameAttrList* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.attr_.InternalSwap(&other->_impl_.attr_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
}

::google::protobuf::Metadata NameAttrList::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace opencv_tensorflow
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_attr_5fvalue_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
